Update doxygen html

This commit is contained in:
Maneesh Gupta
2016-04-16 14:55:10 +05:30
parent dc4c174a54
commit fd49c9eb15
190 changed files with 5431 additions and 10893 deletions
+1 -1
View File
@@ -1,6 +1,6 @@
var searchData=
[
['texture',['texture',['../structtexture.html',1,'texture< T, texType, hipTextureReadMode >'],['../group__Texture.html',1,'(Global Namespace)']]],
['texture_20reference_20management',['Texture Reference Management',['../group__Texture.html',1,'']]],
['texturereference',['textureReference',['../structtextureReference.html',1,'']]],
['totalconstmem',['totalConstMem',['../structhipDeviceProp__t.html#a29880232c56120be3455ce00d5379665',1,'hipDeviceProp_t']]],
['totalglobalmem',['totalGlobalMem',['../structhipDeviceProp__t.html#acedd6a2d23423441e4bf51c4a1b719f9',1,'hipDeviceProp_t']]]
@@ -3,7 +3,7 @@
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta name="generator" content="Doxygen 1.8.6">
<link rel="stylesheet" type="text/css" href="search.css"/>
<script type="text/javascript" src="groups_8.js"></script>
<script type="text/javascript" src="all_15.js"></script>
<script type="text/javascript" src="search.js"></script>
</head>
<body class="SRPage">
+4
View File
@@ -0,0 +1,4 @@
var searchData=
[
['z',['z',['../structdim3.html#a866e38993ecc4e76fd47311236c16b04',1,'dim3']]]
];
-1
View File
@@ -1,5 +1,4 @@
var searchData=
[
['getproperties',['getProperties',['../structihipDevice__t.html#a0abb382f1bcdda80028f9a8307e50561',1,'ihipDevice_t']]],
['global_20enum_20and_20defines',['Global enum and defines',['../group__GlobalDefs.html',1,'']]]
];
+57 -55
View File
@@ -21,12 +21,9 @@ var searchData=
['hcc_2dspecific_20accessors',['HCC-Specific Accessors',['../group__HCC__Specific.html',1,'']]],
['hip_20environment_20variables',['HIP Environment Variables',['../group__HIP-ENV.html',1,'']]],
['hip_5fhcc_2ecpp',['hip_hcc.cpp',['../hip__hcc_8cpp.html',1,'']]],
['hip_5flaunch_5fblocking',['HIP_LAUNCH_BLOCKING',['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING():&#160;hip_hcc2.cpp']]],
['hip_5fprint_5fenv',['HIP_PRINT_ENV',['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV():&#160;hip_hcc2.cpp']]],
['hip_5fruntime_2eh',['hip_runtime.h',['../hcc__detail_2hip__runtime_8h.html',1,'']]],
['hip_5fruntime_5fapi_2eh',['hip_runtime_api.h',['../hcc__detail_2hip__runtime__api_8h.html',1,'']]],
['hip_5ftexture_2eh',['hip_texture.h',['../hip__texture_8h.html',1,'']]],
['hip_5ftrace_5fapi',['HIP_TRACE_API',['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API():&#160;hip_hcc2.cpp']]],
['hip_5fvector_5ftypes_2eh',['hip_vector_types.h',['../hcc__detail_2hip__vector__types_8h.html',1,'']]],
['hipchannelformatdesc',['hipChannelFormatDesc',['../structhipChannelFormatDesc.html',1,'']]],
['hipdevicearch_5ft',['hipDeviceArch_t',['../structhipDeviceArch__t.html',1,'']]],
@@ -56,18 +53,18 @@ var searchData=
['hipdeviceattributepcideviceid',['hipDeviceAttributePciDeviceId',['../group__GlobalDefs.html#ggacc0acd7b9bda126c6bb3dfd6e2796d7ca955d90286e87be9e3528f0b817ab32ff',1,'hip_runtime_api.h']]],
['hipdeviceattributetotalconstantmemory',['hipDeviceAttributeTotalConstantMemory',['../group__GlobalDefs.html#ggacc0acd7b9bda126c6bb3dfd6e2796d7cac6089ac3a0f9c77cc382fb0eaa73ae9c',1,'hip_runtime_api.h']]],
['hipdeviceattributewarpsize',['hipDeviceAttributeWarpSize',['../group__GlobalDefs.html#ggacc0acd7b9bda126c6bb3dfd6e2796d7caffd94133e823247a6f1215343232f6ec',1,'hip_runtime_api.h']]],
['hipdevicecanaccesspeer',['hipDeviceCanAccessPeer',['../group__PeerToPeer.html#gab53a55dbc087ff659918fd04287de3d3',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int device, int peerDevice):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#gab53a55dbc087ff659918fd04287de3d3',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int device, int peerDevice):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#gab53a55dbc087ff659918fd04287de3d3',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int device, int peerDevice):&#160;hip_hcc2.cpp']]],
['hipdevicedisablepeeraccess',['hipDeviceDisablePeerAccess',['../group__PeerToPeer.html#ga41e60c01f63597529da1cd77bdd55379',1,'hipDeviceDisablePeerAccess(int peerDevice):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#ga41e60c01f63597529da1cd77bdd55379',1,'hipDeviceDisablePeerAccess(int peerDevice):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#ga41e60c01f63597529da1cd77bdd55379',1,'hipDeviceDisablePeerAccess(int peerDevice):&#160;hip_hcc2.cpp']]],
['hipdeviceenablepeeraccess',['hipDeviceEnablePeerAccess',['../group__PeerToPeer.html#ga098e0d626edbfb69b66d141a5a8b7dc6',1,'hipDeviceEnablePeerAccess(int peerDevice, unsigned int flags):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#ga098e0d626edbfb69b66d141a5a8b7dc6',1,'hipDeviceEnablePeerAccess(int peerDevice, unsigned int flags):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#ga098e0d626edbfb69b66d141a5a8b7dc6',1,'hipDeviceEnablePeerAccess(int peerDevice, unsigned int flags):&#160;hip_hcc2.cpp']]],
['hipdevicegetattribute',['hipDeviceGetAttribute',['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device):&#160;hip_hcc.cpp'],['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device):&#160;hip_hcc.cpp'],['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device):&#160;hip_hcc2.cpp']]],
['hipdevicegetcacheconfig',['hipDeviceGetCacheConfig',['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig):&#160;hip_hcc.cpp'],['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig):&#160;hip_hcc.cpp'],['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig):&#160;hip_hcc2.cpp']]],
['hipdevicegetsharedmemconfig',['hipDeviceGetSharedMemConfig',['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig):&#160;hip_hcc.cpp'],['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig):&#160;hip_hcc.cpp'],['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig):&#160;hip_hcc2.cpp']]],
['hipdevicecanaccesspeer',['hipDeviceCanAccessPeer',['../group__PeerToPeer.html#ga0a1c9ccd775758d9d7d5b5a1f525b719',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int deviceId, int peerDeviceId):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga0a1c9ccd775758d9d7d5b5a1f525b719',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int deviceId, int peerDeviceId):&#160;hip_peer.cpp']]],
['hipdevicedisablepeeraccess',['hipDeviceDisablePeerAccess',['../group__PeerToPeer.html#ga85030c72824fb60aaddc7374ab60481b',1,'hipDeviceDisablePeerAccess(int peerDeviceId):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga85030c72824fb60aaddc7374ab60481b',1,'hipDeviceDisablePeerAccess(int peerDeviceId):&#160;hip_peer.cpp']]],
['hipdeviceenablepeeraccess',['hipDeviceEnablePeerAccess',['../group__PeerToPeer.html#ga0caca59034134d7a7bb893cc1caa653e',1,'hipDeviceEnablePeerAccess(int peerDeviceId, unsigned int flags):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga0caca59034134d7a7bb893cc1caa653e',1,'hipDeviceEnablePeerAccess(int peerDeviceId, unsigned int flags):&#160;hip_peer.cpp']]],
['hipdevicegetattribute',['hipDeviceGetAttribute',['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device):&#160;hip_device.cpp'],['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device):&#160;hip_device.cpp']]],
['hipdevicegetcacheconfig',['hipDeviceGetCacheConfig',['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig):&#160;hip_device.cpp'],['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig):&#160;hip_device.cpp']]],
['hipdevicegetsharedmemconfig',['hipDeviceGetSharedMemConfig',['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig):&#160;hip_device.cpp'],['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig):&#160;hip_device.cpp']]],
['hipdeviceprop_5ft',['hipDeviceProp_t',['../structhipDeviceProp__t.html',1,'']]],
['hipdevicereset',['hipDeviceReset',['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void):&#160;hip_hcc.cpp'],['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void):&#160;hip_hcc.cpp'],['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void):&#160;hip_hcc2.cpp']]],
['hipdevicesetcacheconfig',['hipDeviceSetCacheConfig',['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_hcc.cpp'],['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_hcc.cpp'],['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_hcc2.cpp']]],
['hipdevicesetsharedmemconfig',['hipDeviceSetSharedMemConfig',['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config):&#160;hip_hcc.cpp'],['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config):&#160;hip_hcc.cpp'],['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config):&#160;hip_hcc2.cpp']]],
['hipdevicesynchronize',['hipDeviceSynchronize',['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void):&#160;hip_hcc.cpp'],['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void):&#160;hip_hcc.cpp'],['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void):&#160;hip_hcc2.cpp']]],
['hipdrivergetversion',['hipDriverGetVersion',['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion):&#160;hip_hcc.cpp'],['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion):&#160;hip_hcc.cpp'],['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion):&#160;hip_hcc2.cpp']]],
['hipdevicereset',['hipDeviceReset',['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void):&#160;hip_device.cpp'],['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void):&#160;hip_device.cpp']]],
['hipdevicesetcacheconfig',['hipDeviceSetCacheConfig',['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_device.cpp'],['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_device.cpp']]],
['hipdevicesetsharedmemconfig',['hipDeviceSetSharedMemConfig',['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config):&#160;hip_device.cpp'],['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config):&#160;hip_device.cpp']]],
['hipdevicesynchronize',['hipDeviceSynchronize',['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void):&#160;hip_device.cpp'],['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void):&#160;hip_device.cpp']]],
['hipdrivergetversion',['hipDriverGetVersion',['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion):&#160;hip_peer.cpp'],['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion):&#160;hip_peer.cpp']]],
['hiperror_5ft',['hipError_t',['../group__GlobalDefs.html#gadf5010f6e140a53ecbdf949e73e87594',1,'hip_runtime_api.h']]],
['hiperrorinitializationerror',['hipErrorInitializationError',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a7e935ae88ee1f9ff3920156ac6864520',1,'hip_runtime_api.h']]],
['hiperrorinvaliddevice',['hipErrorInvalidDevice',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a07ab9b704ea693c1781a52741c60cd0d',1,'hip_runtime_api.h']]],
@@ -80,6 +77,8 @@ var searchData=
['hiperrornodevice',['hipErrorNoDevice',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594ad4406972c318df36d231310a15131c24',1,'hip_runtime_api.h']]],
['hiperrornotready',['hipErrorNotReady',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594aa9638063c8746a9d1fda2b2069a0a9f1',1,'hip_runtime_api.h']]],
['hiperroroutofresources',['hipErrorOutOfResources',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a60c1c080b79bdde9ef5e808f974ac9ed',1,'hip_runtime_api.h']]],
['hiperrorpeeraccessalreadyenabled',['hipErrorPeerAccessAlreadyEnabled',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a5399c146f91246f8b77abcd4ea30e7ac',1,'hip_runtime_api.h']]],
['hiperrorpeeraccessnotenabled',['hipErrorPeerAccessNotEnabled',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a2ee0bf2e64840f253e4a1b12bbaf2d09',1,'hip_runtime_api.h']]],
['hiperrorruntimememory',['hipErrorRuntimeMemory',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a1159eb9a6be66bea740a8bfb61378723',1,'hip_runtime_api.h']]],
['hiperrorruntimeother',['hipErrorRuntimeOther',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a44f847c5914be2177feac107dcb096d1',1,'hip_runtime_api.h']]],
['hiperrortbd',['hipErrorTbd',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594ab556409e11ddb0c4cf77a2f4fc91ea9e',1,'hip_runtime_api.h']]],
@@ -87,75 +86,78 @@ var searchData=
['hiperrorunknownsymbol',['hipErrorUnknownSymbol',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a45b297e6c3b2029dce1348658421481b',1,'hip_runtime_api.h']]],
['hipevent_5ft',['hipEvent_t',['../structhipEvent__t.html',1,'']]],
['hipeventblockingsync',['hipEventBlockingSync',['../group__GlobalDefs.html#gafa1c076a5b991763a98695063f1ea11d',1,'hip_runtime_api.h']]],
['hipeventcreatewithflags',['hipEventCreateWithFlags',['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags):&#160;hip_hcc.cpp'],['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags):&#160;hip_hcc.cpp'],['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags):&#160;hip_hcc2.cpp']]],
['hipeventcreate',['hipEventCreate',['../group__Event.html#ga5df2309c9f29ca4c8e669db658d411b4',1,'hipEventCreate(hipEvent_t *event):&#160;hip_event.cpp'],['../group__Event.html#ga5df2309c9f29ca4c8e669db658d411b4',1,'hipEventCreate(hipEvent_t *event):&#160;hip_event.cpp']]],
['hipeventcreatewithflags',['hipEventCreateWithFlags',['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags):&#160;hip_event.cpp'],['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags):&#160;hip_event.cpp']]],
['hipeventdefault',['hipEventDefault',['../group__GlobalDefs.html#ga122a5853359eba97cf047ddd153740f0',1,'hip_runtime_api.h']]],
['hipeventdestroy',['hipEventDestroy',['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event):&#160;hip_hcc.cpp'],['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event):&#160;hip_hcc.cpp'],['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event):&#160;hip_hcc2.cpp']]],
['hipeventdestroy',['hipEventDestroy',['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event):&#160;hip_event.cpp'],['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event):&#160;hip_event.cpp']]],
['hipeventdisabletiming',['hipEventDisableTiming',['../group__GlobalDefs.html#ga3c0f44a85e36a4c67671da6bcdad0351',1,'hip_runtime_api.h']]],
['hipeventelapsedtime',['hipEventElapsedTime',['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop):&#160;hip_hcc.cpp'],['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop):&#160;hip_hcc.cpp'],['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop):&#160;hip_hcc2.cpp']]],
['hipeventelapsedtime',['hipEventElapsedTime',['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop):&#160;hip_event.cpp'],['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop):&#160;hip_event.cpp']]],
['hipeventinterprocess',['hipEventInterprocess',['../group__GlobalDefs.html#ga0f01d74059baa704e42aeff8222166bb',1,'hip_runtime_api.h']]],
['hipeventquery',['hipEventQuery',['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event):&#160;hip_hcc.cpp'],['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event):&#160;hip_hcc.cpp'],['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event):&#160;hip_hcc2.cpp']]],
['hipeventrecord',['hipEventRecord',['../group__Event.html#gace88ebd8c7ec42a6c2cebda2e8b0cb38',1,'hipEventRecord(hipEvent_t event, hipStream_t stream=NULL):&#160;hip_hcc.cpp'],['../group__Event.html#gace88ebd8c7ec42a6c2cebda2e8b0cb38',1,'hipEventRecord(hipEvent_t event, hipStream_t stream):&#160;hip_hcc.cpp'],['../group__Event.html#gace88ebd8c7ec42a6c2cebda2e8b0cb38',1,'hipEventRecord(hipEvent_t event, hipStream_t stream):&#160;hip_hcc2.cpp']]],
['hipeventsynchronize',['hipEventSynchronize',['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event):&#160;hip_hcc.cpp'],['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event):&#160;hip_hcc.cpp'],['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event):&#160;hip_hcc2.cpp']]],
['hipeventquery',['hipEventQuery',['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event):&#160;hip_event.cpp'],['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event):&#160;hip_event.cpp']]],
['hipeventrecord',['hipEventRecord',['../group__Event.html#ga553b6f7a8e7b7dd9536d8a64c24d7e29',1,'hipEventRecord(hipEvent_t event, hipStream_t stream):&#160;hip_event.cpp'],['../group__Event.html#ga553b6f7a8e7b7dd9536d8a64c24d7e29',1,'hipEventRecord(hipEvent_t event, hipStream_t stream):&#160;hip_event.cpp']]],
['hipeventsynchronize',['hipEventSynchronize',['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event):&#160;hip_event.cpp'],['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event):&#160;hip_event.cpp']]],
['hipfiltermodepoint',['hipFilterModePoint',['../hip__texture_8h.html#aa2f0b6002b81d0a43a808cb880bb21e6a56ede038ab7c805ec4b5b61d2b678dfc',1,'hip_texture.h']]],
['hipfree',['hipFree',['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr):&#160;hip_hcc2.cpp']]],
['hipfreehost',['hipFreeHost',['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr) __attribute__((deprecated(&quot;use hipHostFree instead&quot;))):&#160;hip_hcc.cpp'],['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr):&#160;hip_hcc.cpp'],['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr):&#160;hip_hcc2.cpp']]],
['hipfree',['hipFree',['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr):&#160;hip_memory.cpp'],['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr):&#160;hip_memory.cpp']]],
['hipfreehost',['hipFreeHost',['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr) __attribute__((deprecated(&quot;use hipHostFree instead&quot;))):&#160;hip_memory.cpp'],['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr):&#160;hip_memory.cpp']]],
['hipfunccache',['hipFuncCache',['../group__GlobalDefs.html#gac7e4bfd88340fc06642136c839a3d822',1,'hipFuncCache():&#160;hip_runtime_api.h'],['../group__GlobalDefs.html#gaad15dc7939a0a25b16e4aa161fb41eee',1,'hipFuncCache():&#160;hip_runtime_api.h']]],
['hipfunccachepreferequal',['hipFuncCachePreferEqual',['../group__GlobalDefs.html#ggac7e4bfd88340fc06642136c839a3d822a0ddab0e840107634a152033103be44d7',1,'hip_runtime_api.h']]],
['hipfunccachepreferl1',['hipFuncCachePreferL1',['../group__GlobalDefs.html#ggac7e4bfd88340fc06642136c839a3d822a636a3c140db6b9d4a8bf7d5a61c398c5',1,'hip_runtime_api.h']]],
['hipfunccacheprefernone',['hipFuncCachePreferNone',['../group__GlobalDefs.html#ggac7e4bfd88340fc06642136c839a3d822a0813fbaa008ce1231ff9fed3911eb3af',1,'hip_runtime_api.h']]],
['hipfunccacheprefershared',['hipFuncCachePreferShared',['../group__GlobalDefs.html#ggac7e4bfd88340fc06642136c839a3d822a9b34337dfbadba25ed2aa270bbcabc43',1,'hip_runtime_api.h']]],
['hipfuncsetcacheconfig',['hipFuncSetCacheConfig',['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache config):&#160;hip_hcc.cpp'],['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_hcc.cpp'],['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_hcc2.cpp']]],
['hipgetdevice',['hipGetDevice',['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device):&#160;hip_hcc.cpp'],['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device):&#160;hip_hcc.cpp'],['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device):&#160;hip_hcc2.cpp']]],
['hipgetdevicecount',['hipGetDeviceCount',['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count):&#160;hip_hcc.cpp'],['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count):&#160;hip_hcc.cpp'],['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count):&#160;hip_hcc2.cpp']]],
['hipgetdeviceproperties',['hipGetDeviceProperties',['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *prop, int device):&#160;hip_hcc.cpp'],['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *props, int device):&#160;hip_hcc.cpp'],['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *props, int device):&#160;hip_hcc2.cpp']]],
['hipgeterrorname',['hipGetErrorName',['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error):&#160;hip_hcc.cpp'],['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error):&#160;hip_hcc.cpp'],['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error):&#160;hip_hcc2.cpp']]],
['hipgeterrorstring',['hipGetErrorString',['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error):&#160;hip_hcc.cpp'],['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error):&#160;hip_hcc.cpp'],['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error):&#160;hip_hcc2.cpp']]],
['hipgetlasterror',['hipGetLastError',['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError(void):&#160;hip_hcc.cpp'],['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError():&#160;hip_hcc.cpp'],['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError():&#160;hip_hcc2.cpp']]],
['hiphccgetaccelerator',['hipHccGetAccelerator',['../group__HCC__Specific.html#ga0d24b3157fd1b16d38672bb157ec4cd4',1,'hipHccGetAccelerator(int deviceId, hc::accelerator *acc):&#160;hip_hcc.cpp'],['../group__HCC__Specific.html#ga0d24b3157fd1b16d38672bb157ec4cd4',1,'hipHccGetAccelerator(int deviceId, hc::accelerator *acc):&#160;hip_hcc.cpp'],['../group__HCC__Specific.html#ga0d24b3157fd1b16d38672bb157ec4cd4',1,'hipHccGetAccelerator(int deviceId, hc::accelerator *acc):&#160;hip_hcc2.cpp']]],
['hiphccgetacceleratorview',['hipHccGetAcceleratorView',['../group__HCC__Specific.html#ga1a7087ea9c3c3323270d7cce73650b44',1,'hipHccGetAcceleratorView(hipStream_t stream, hc::accelerator_view **av):&#160;hip_hcc.cpp'],['../group__HCC__Specific.html#ga1a7087ea9c3c3323270d7cce73650b44',1,'hipHccGetAcceleratorView(hipStream_t stream, hc::accelerator_view **av):&#160;hip_hcc.cpp'],['../group__HCC__Specific.html#ga1a7087ea9c3c3323270d7cce73650b44',1,'hipHccGetAcceleratorView(hipStream_t stream, hc::accelerator_view **av):&#160;hip_hcc2.cpp']]],
['hiphostfree',['hipHostFree',['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr):&#160;hip_hcc.cpp']]],
['hiphostgetdevicepointer',['hipHostGetDevicePointer',['../group__Memory.html#ga8fa7a0478020b835a24785cd6bb89725',1,'hipHostGetDevicePointer(void **devPtr, void *hstPtr, unsigned int flags):&#160;hip_runtime_api.h'],['../hip__hcc_8cpp.html#a59f9f57c495531c8bb12f506e915399e',1,'hipHostGetDevicePointer(void **devicePointer, void *hostPointer, unsigned flags):&#160;hip_hcc.cpp']]],
['hiphostgetflags',['hipHostGetFlags',['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr):&#160;hip_hcc2.cpp']]],
['hiphostmalloc',['hipHostMalloc',['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t size, unsigned int flags):&#160;hip_hcc.cpp'],['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t sizeBytes, unsigned int flags):&#160;hip_hcc.cpp']]],
['hipfuncsetcacheconfig',['hipFuncSetCacheConfig',['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache config):&#160;hip_device.cpp'],['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_device.cpp']]],
['hipgetdevice',['hipGetDevice',['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device):&#160;hip_device.cpp'],['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device):&#160;hip_device.cpp']]],
['hipgetdevicecount',['hipGetDeviceCount',['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count):&#160;hip_device.cpp'],['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count):&#160;hip_device.cpp']]],
['hipgetdeviceproperties',['hipGetDeviceProperties',['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *prop, int device):&#160;hip_device.cpp'],['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *props, int device):&#160;hip_device.cpp']]],
['hipgeterrorname',['hipGetErrorName',['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error):&#160;hip_error.cpp'],['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error):&#160;hip_error.cpp']]],
['hipgeterrorstring',['hipGetErrorString',['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error):&#160;hip_error.cpp'],['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error):&#160;hip_error.cpp']]],
['hipgetlasterror',['hipGetLastError',['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError(void):&#160;hip_error.cpp'],['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError():&#160;hip_error.cpp']]],
['hiphccgetaccelerator',['hipHccGetAccelerator',['../hip__hcc_8cpp.html#a0d24b3157fd1b16d38672bb157ec4cd4',1,'hip_hcc.cpp']]],
['hiphccgetacceleratorview',['hipHccGetAcceleratorView',['../hip__hcc_8cpp.html#a1a7087ea9c3c3323270d7cce73650b44',1,'hip_hcc.cpp']]],
['hiphostfree',['hipHostFree',['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr):&#160;hip_memory.cpp'],['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr):&#160;hip_memory.cpp']]],
['hiphostgetdevicepointer',['hipHostGetDevicePointer',['../group__Memory.html#ga8fa7a0478020b835a24785cd6bb89725',1,'hip_runtime_api.h']]],
['hiphostgetflags',['hipHostGetFlags',['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr):&#160;hip_memory.cpp'],['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr):&#160;hip_memory.cpp']]],
['hiphostmalloc',['hipHostMalloc',['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t size, unsigned int flags):&#160;hip_memory.cpp'],['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t sizeBytes, unsigned int flags):&#160;hip_memory.cpp']]],
['hiphostmallocdefault',['hipHostMallocDefault',['../group__GlobalDefs.html#gad594ec51cb5b5e946c1e354bf80bddc7',1,'hip_runtime_api.h']]],
['hiphostregister',['hipHostRegister',['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags):&#160;hip_hcc.cpp'],['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags):&#160;hip_hcc.cpp'],['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags):&#160;hip_hcc2.cpp']]],
['hiphostregister',['hipHostRegister',['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags):&#160;hip_memory.cpp'],['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags):&#160;hip_memory.cpp']]],
['hiphostregisterdefault',['hipHostRegisterDefault',['../group__GlobalDefs.html#gac7c100d241ff84ad10109bb00b7b25dc',1,'hip_runtime_api.h']]],
['hiphostregisteriomemory',['hipHostRegisterIoMemory',['../group__GlobalDefs.html#gaefa79f1b4481d6a1d1091c14b24f33d0',1,'hip_runtime_api.h']]],
['hiphostregistermapped',['hipHostRegisterMapped',['../group__GlobalDefs.html#gacfa4edcfcb39fc61bff6bdecb14d7618',1,'hip_runtime_api.h']]],
['hiphostregisterportable',['hipHostRegisterPortable',['../group__GlobalDefs.html#ga2db444f2315d412d3c7ba80ec6049583',1,'hip_runtime_api.h']]],
['hiphostunregister',['hipHostUnregister',['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr):&#160;hip_hcc2.cpp']]],
['hipmalloc',['hipMalloc',['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t size):&#160;hip_hcc.cpp'],['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t sizeBytes):&#160;hip_hcc.cpp'],['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t sizeBytes):&#160;hip_hcc2.cpp']]],
['hipmallochost',['hipMallocHost',['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t size) __attribute__((deprecated(&quot;use hipHostMalloc instead&quot;))):&#160;hip_hcc.cpp'],['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t sizeBytes):&#160;hip_hcc.cpp'],['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t sizeBytes):&#160;hip_hcc2.cpp']]],
['hipmemcpy',['hipMemcpy',['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind):&#160;hip_hcc.cpp'],['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind):&#160;hip_hcc.cpp'],['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind):&#160;hip_hcc2.cpp']]],
['hipmemcpyasync',['hipMemcpyAsync',['../group__Memory.html#ga8ad5a0b13458917e1b9437732b21af54',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream=0):&#160;hip_hcc.cpp'],['../group__Memory.html#ga8ad5a0b13458917e1b9437732b21af54',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream):&#160;hip_hcc.cpp'],['../group__Memory.html#ga8ad5a0b13458917e1b9437732b21af54',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream):&#160;hip_hcc2.cpp']]],
['hiphostunregister',['hipHostUnregister',['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr):&#160;hip_memory.cpp'],['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr):&#160;hip_memory.cpp']]],
['hipmalloc',['hipMalloc',['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t size):&#160;hip_memory.cpp'],['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t sizeBytes):&#160;hip_memory.cpp']]],
['hipmallochost',['hipMallocHost',['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t size) __attribute__((deprecated(&quot;use hipHostMalloc instead&quot;))):&#160;hip_memory.cpp'],['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t sizeBytes):&#160;hip_memory.cpp']]],
['hipmemcpy',['hipMemcpy',['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind):&#160;hip_memory.cpp'],['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind):&#160;hip_memory.cpp']]],
['hipmemcpyasync',['hipMemcpyAsync',['../group__Memory.html#gad55fa9f5980b711bc93c52820149ba18',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream):&#160;hip_memory.cpp'],['../group__Memory.html#gad55fa9f5980b711bc93c52820149ba18',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream):&#160;hip_memory.cpp']]],
['hipmemcpydefault',['hipMemcpyDefault',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18a4e37107e416f79a2edf2b6534163c823',1,'hip_runtime_api.h']]],
['hipmemcpydevicetodevice',['hipMemcpyDeviceToDevice',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18abd05a09d3105e0ce25b34dd91cf83f88',1,'hip_runtime_api.h']]],
['hipmemcpydevicetohost',['hipMemcpyDeviceToHost',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18aba2505e9ce1e5382f17730bc670917d1',1,'hip_runtime_api.h']]],
['hipmemcpyhosttodevice',['hipMemcpyHostToDevice',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18aff32175ecb0c7113200286eff8211008',1,'hip_runtime_api.h']]],
['hipmemcpyhosttohost',['hipMemcpyHostToHost',['../group__GlobalDefs.html#gga232e222db36b1fc672ba98054d036a18a9d66b705aa85a9c83f0f533cef70d0af',1,'hip_runtime_api.h']]],
['hipmemcpykind',['hipMemcpyKind',['../group__GlobalDefs.html#ga232e222db36b1fc672ba98054d036a18',1,'hip_runtime_api.h']]],
['hipmemcpypeer',['hipMemcpyPeer',['../group__PeerToPeer.html#ga72ae9e7f498ab5684580892a5d7d8e2d',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#ga72ae9e7f498ab5684580892a5d7d8e2d',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#ga72ae9e7f498ab5684580892a5d7d8e2d',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes):&#160;hip_hcc2.cpp']]],
['hipmemcpypeerasync',['hipMemcpyPeerAsync',['../group__PeerToPeer.html#gab6211c18ca1e23252ef080cd6be855ca',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream=0):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#gab6211c18ca1e23252ef080cd6be855ca',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream):&#160;hip_hcc.cpp'],['../group__PeerToPeer.html#gab6211c18ca1e23252ef080cd6be855ca',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream):&#160;hip_hcc2.cpp']]],
['hipmemcpytosymbol',['hipMemcpyToSymbol',['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t sizeBytes, size_t offset, hipMemcpyKind kind):&#160;hip_hcc.cpp'],['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t count, size_t offset, hipMemcpyKind kind):&#160;hip_hcc.cpp'],['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t count, size_t offset, hipMemcpyKind kind):&#160;hip_hcc2.cpp']]],
['hipmemgetinfo',['hipMemGetInfo',['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total):&#160;hip_hcc.cpp'],['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total):&#160;hip_hcc.cpp'],['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total):&#160;hip_hcc2.cpp']]],
['hipmemset',['hipMemset',['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes):&#160;hip_hcc.cpp'],['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes):&#160;hip_hcc.cpp'],['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes):&#160;hip_hcc2.cpp']]],
['hipmemsetasync',['hipMemsetAsync',['../group__Memory.html#gaee4ed665ce0a60c661a809c175320a0c',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t=0):&#160;hip_hcc.cpp'],['../group__Memory.html#gaee4ed665ce0a60c661a809c175320a0c',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream):&#160;hip_hcc.cpp'],['../group__Memory.html#gaee4ed665ce0a60c661a809c175320a0c',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream):&#160;hip_hcc2.cpp']]],
['hipmemcpykind',['hipMemcpyKind',['../group__GlobalDefs.html#ga232e222db36b1fc672ba98054d036a18',1,'hipMemcpyKind():&#160;hip_runtime_api.h'],['../group__GlobalDefs.html#ga0c04e67413ce030817361f02673e5c85',1,'hipMemcpyKind():&#160;hip_runtime_api.h']]],
['hipmemcpypeer',['hipMemcpyPeer',['../group__PeerToPeer.html#ga5512f45e25c08052667c8ffe7162333b',1,'hipMemcpyPeer(void *dst, int dstDeviceId, const void *src, int srcDeviceId, size_t sizeBytes):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga5512f45e25c08052667c8ffe7162333b',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes):&#160;hip_peer.cpp']]],
['hipmemcpypeerasync',['hipMemcpyPeerAsync',['../group__PeerToPeer.html#ga216f951370c931d22e80c089ab724ed9',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga216f951370c931d22e80c089ab724ed9',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream):&#160;hip_peer.cpp']]],
['hipmemcpytosymbol',['hipMemcpyToSymbol',['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t sizeBytes, size_t offset, hipMemcpyKind kind):&#160;hip_memory.cpp'],['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t count, size_t offset, hipMemcpyKind kind):&#160;hip_memory.cpp']]],
['hipmemgetinfo',['hipMemGetInfo',['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total):&#160;hip_memory.cpp'],['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total):&#160;hip_memory.cpp']]],
['hipmemset',['hipMemset',['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes):&#160;hip_memory.cpp'],['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes):&#160;hip_memory.cpp']]],
['hipmemsetasync',['hipMemsetAsync',['../group__Memory.html#gae7d90e14c387e49f10db597f12915c54',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream):&#160;hip_memory.cpp'],['../group__Memory.html#gae7d90e14c387e49f10db597f12915c54',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream):&#160;hip_memory.cpp']]],
['hippeekatlasterror',['hipPeekAtLastError',['../group__Error.html#ga1dd660bc739f7e13edd34615660f0148',1,'hip_runtime_api.h']]],
['hippointerattribute_5ft',['hipPointerAttribute_t',['../structhipPointerAttribute__t.html',1,'']]],
['hippointergetattributes',['hipPointerGetAttributes',['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr):&#160;hip_hcc.cpp'],['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr):&#160;hip_hcc2.cpp']]],
['hippointergetattributes',['hipPointerGetAttributes',['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr):&#160;hip_memory.cpp'],['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr):&#160;hip_memory.cpp']]],
['hipreadmodeelementtype',['hipReadModeElementType',['../hip__texture_8h.html#a442e950774f7306dc33692e358c92c94a829645801202174d052d667ffa4e1b8d',1,'hip_texture.h']]],
['hipsetdevice',['hipSetDevice',['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device):&#160;hip_hcc.cpp'],['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device):&#160;hip_hcc.cpp'],['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device):&#160;hip_hcc2.cpp']]],
['hipsetdevice',['hipSetDevice',['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device):&#160;hip_device.cpp'],['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device):&#160;hip_device.cpp']]],
['hipsetdeviceflags',['hipSetDeviceFlags',['../group__Device.html#ga6e54db382768827e84725632018307aa',1,'hip_runtime_api.h']]],
['hipsharedmembanksizedefault',['hipSharedMemBankSizeDefault',['../group__GlobalDefs.html#gga2e17b71d94ac350f2ccd914fd49d104eaf5b325c9b7bde878913f768eaba5014d',1,'hip_runtime_api.h']]],
['hipsharedmembanksizeeightbyte',['hipSharedMemBankSizeEightByte',['../group__GlobalDefs.html#gga2e17b71d94ac350f2ccd914fd49d104ea64518b4f5a25f536c883330167e79258',1,'hip_runtime_api.h']]],
['hipsharedmembanksizefourbyte',['hipSharedMemBankSizeFourByte',['../group__GlobalDefs.html#gga2e17b71d94ac350f2ccd914fd49d104ea0a95a6e0c33106c42d66ab9476ff954a',1,'hip_runtime_api.h']]],
['hipsharedmemconfig',['hipSharedMemConfig',['../group__GlobalDefs.html#ga2e17b71d94ac350f2ccd914fd49d104e',1,'hipSharedMemConfig():&#160;hip_runtime_api.h'],['../group__GlobalDefs.html#ga6b1ca424fa26a5fb718937d662eaee7f',1,'hipSharedMemConfig():&#160;hip_runtime_api.h']]],
['hipstreamcreatewithflags',['hipStreamCreateWithFlags',['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags):&#160;hip_hcc.cpp'],['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags):&#160;hip_hcc.cpp'],['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags):&#160;hip_hcc2.cpp']]],
['hipstreamcreate',['hipStreamCreate',['../group__Stream.html#gaff5b62d6e9502d80879f7176f4d03102',1,'hipStreamCreate(hipStream_t *stream):&#160;hip_stream.cpp'],['../group__Stream.html#gaff5b62d6e9502d80879f7176f4d03102',1,'hipStreamCreate(hipStream_t *stream):&#160;hip_stream.cpp']]],
['hipstreamcreatewithflags',['hipStreamCreateWithFlags',['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags):&#160;hip_stream.cpp'],['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags):&#160;hip_stream.cpp']]],
['hipstreamdefault',['hipStreamDefault',['../group__GlobalDefs.html#ga6df5f70eb976836ab3598cacf0ffcdf9',1,'hip_runtime_api.h']]],
['hipstreamdestroy',['hipStreamDestroy',['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream):&#160;hip_hcc.cpp'],['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream):&#160;hip_hcc.cpp'],['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream):&#160;hip_hcc2.cpp']]],
['hipstreamgetflags',['hipStreamGetFlags',['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags):&#160;hip_hcc.cpp'],['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags):&#160;hip_hcc.cpp'],['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags):&#160;hip_hcc2.cpp']]],
['hipstreamdestroy',['hipStreamDestroy',['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream):&#160;hip_stream.cpp'],['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream):&#160;hip_stream.cpp']]],
['hipstreamgetflags',['hipStreamGetFlags',['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags):&#160;hip_stream.cpp'],['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags):&#160;hip_stream.cpp']]],
['hipstreamnonblocking',['hipStreamNonBlocking',['../group__GlobalDefs.html#gaaba9ae995d9b43b7d1ee70c6fa12c57d',1,'hip_runtime_api.h']]],
['hipstreamsynchronize',['hipStreamSynchronize',['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream):&#160;hip_hcc.cpp'],['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream):&#160;hip_hcc.cpp'],['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream):&#160;hip_hcc2.cpp']]],
['hipstreamwaitevent',['hipStreamWaitEvent',['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags):&#160;hip_hcc.cpp'],['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags):&#160;hip_hcc.cpp'],['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags):&#160;hip_hcc2.cpp']]],
['hipstreamsynchronize',['hipStreamSynchronize',['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream):&#160;hip_stream.cpp'],['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream):&#160;hip_stream.cpp']]],
['hipstreamwaitevent',['hipStreamWaitEvent',['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags):&#160;hip_stream.cpp'],['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags):&#160;hip_stream.cpp']]],
['hipsuccess',['hipSuccess',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594aadfbdb847b149723c684ebd764556063',1,'hip_runtime_api.h']]],
['hiptexturefiltermode',['hipTextureFilterMode',['../hip__texture_8h.html#aa2f0b6002b81d0a43a808cb880bb21e6',1,'hip_texture.h']]],
['hiptexturereadmode',['hipTextureReadMode',['../hip__texture_8h.html#a442e950774f7306dc33692e358c92c94',1,'hip_texture.h']]],
+5 -1
View File
@@ -1,9 +1,13 @@
var searchData=
[
['ihipdevice_5ft',['ihipDevice_t',['../structihipDevice__t.html',1,'']]],
['ihipdevice_5ft',['ihipDevice_t',['../classihipDevice__t.html',1,'']]],
['ihipdevicecriticalbase_5ft',['ihipDeviceCriticalBase_t',['../classihipDeviceCriticalBase__t.html',1,'']]],
['ihipdevicecriticalbase_5ft_3c_20devicemutex_20_3e',['ihipDeviceCriticalBase_t&lt; DeviceMutex &gt;',['../classihipDeviceCriticalBase__t.html',1,'']]],
['ihipevent_5ft',['ihipEvent_t',['../structihipEvent__t.html',1,'']]],
['ihipexception',['ihipException',['../classihipException.html',1,'']]],
['ihipsignal_5ft',['ihipSignal_t',['../structihipSignal__t.html',1,'']]],
['ihipstream_5ft',['ihipStream_t',['../classihipStream__t.html',1,'']]],
['ihipstreamcriticalbase_5ft',['ihipStreamCriticalBase_t',['../classihipStreamCriticalBase__t.html',1,'']]],
['ihipstreamcriticalbase_5ft_3c_20streammutex_20_3e',['ihipStreamCriticalBase_t&lt; StreamMutex &gt;',['../classihipStreamCriticalBase__t.html',1,'']]],
['ismultigpuboard',['isMultiGpuBoard',['../structhipDeviceProp__t.html#a9bb19b2b0cdee8977ed63964532d639d',1,'hipDeviceProp_t']]]
];
+5 -1
View File
@@ -1,4 +1,8 @@
var searchData=
[
['l2cachesize',['l2CacheSize',['../structhipDeviceProp__t.html#a24404decccc16833973c803ced6f3a51',1,'hipDeviceProp_t']]]
['l2cachesize',['l2CacheSize',['../structhipDeviceProp__t.html#a24404decccc16833973c803ced6f3a51',1,'hipDeviceProp_t']]],
['lockedaccessor',['LockedAccessor',['../classLockedAccessor.html',1,'']]],
['lockedbase',['LockedBase',['../structLockedBase.html',1,'']]],
['lockedbase_3c_20devicemutex_20_3e',['LockedBase&lt; DeviceMutex &gt;',['../structLockedBase.html',1,'']]],
['lockedbase_3c_20streammutex_20_3e',['LockedBase&lt; StreamMutex &gt;',['../structLockedBase.html',1,'']]]
];
+6 -2
View File
@@ -1,8 +1,12 @@
var searchData=
[
['ihipdevice_5ft',['ihipDevice_t',['../structihipDevice__t.html',1,'']]],
['ihipdevice_5ft',['ihipDevice_t',['../classihipDevice__t.html',1,'']]],
['ihipdevicecriticalbase_5ft',['ihipDeviceCriticalBase_t',['../classihipDeviceCriticalBase__t.html',1,'']]],
['ihipdevicecriticalbase_5ft_3c_20devicemutex_20_3e',['ihipDeviceCriticalBase_t&lt; DeviceMutex &gt;',['../classihipDeviceCriticalBase__t.html',1,'']]],
['ihipevent_5ft',['ihipEvent_t',['../structihipEvent__t.html',1,'']]],
['ihipexception',['ihipException',['../classihipException.html',1,'']]],
['ihipsignal_5ft',['ihipSignal_t',['../structihipSignal__t.html',1,'']]],
['ihipstream_5ft',['ihipStream_t',['../classihipStream__t.html',1,'']]]
['ihipstream_5ft',['ihipStream_t',['../classihipStream__t.html',1,'']]],
['ihipstreamcriticalbase_5ft',['ihipStreamCriticalBase_t',['../classihipStreamCriticalBase__t.html',1,'']]],
['ihipstreamcriticalbase_5ft_3c_20streammutex_20_3e',['ihipStreamCriticalBase_t&lt; StreamMutex &gt;',['../classihipStreamCriticalBase__t.html',1,'']]]
];
+4 -1
View File
@@ -1,4 +1,7 @@
var searchData=
[
['stagingbuffer',['StagingBuffer',['../structStagingBuffer.html',1,'']]]
['lockedaccessor',['LockedAccessor',['../classLockedAccessor.html',1,'']]],
['lockedbase',['LockedBase',['../structLockedBase.html',1,'']]],
['lockedbase_3c_20devicemutex_20_3e',['LockedBase&lt; DeviceMutex &gt;',['../structLockedBase.html',1,'']]],
['lockedbase_3c_20streammutex_20_3e',['LockedBase&lt; StreamMutex &gt;',['../structLockedBase.html',1,'']]]
];
+1 -2
View File
@@ -1,5 +1,4 @@
var searchData=
[
['texture',['texture',['../structtexture.html',1,'']]],
['texturereference',['textureReference',['../structtextureReference.html',1,'']]]
['stagingbuffer',['StagingBuffer',['../structStagingBuffer.html',1,'']]]
];
+1 -1
View File
@@ -1,4 +1,4 @@
var searchData=
[
['short1',['short1',['../structshort1.html',1,'']]]
['texturereference',['textureReference',['../structtextureReference.html',1,'']]]
];
-5
View File
@@ -1,5 +0,0 @@
var searchData=
[
['texture',['texture',['../structtexture.html',1,'']]],
['texturereference',['textureReference',['../structtextureReference.html',1,'']]]
];
@@ -1,26 +0,0 @@
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html><head><title></title>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta name="generator" content="Doxygen 1.8.6">
<link rel="stylesheet" type="text/css" href="search.css"/>
<script type="text/javascript" src="classes_8.js"></script>
<script type="text/javascript" src="search.js"></script>
</head>
<body class="SRPage">
<div id="SRIndex">
<div class="SRStatus" id="Loading">Loading...</div>
<div id="SRResults"></div>
<script type="text/javascript"><!--
createResults();
--></script>
<div class="SRStatus" id="Searching">Searching...</div>
<div class="SRStatus" id="NoMatches">No Matches</div>
<script type="text/javascript"><!--
document.getElementById("Loading").style.display="none";
document.getElementById("NoMatches").style.display="none";
var searchResults = new SearchResults("searchResults");
searchResults.Search();
--></script>
</div>
</body>
</html>
-10
View File
@@ -1,10 +0,0 @@
var searchData=
[
['uchar1',['uchar1',['../structuchar1.html',1,'']]],
['uint1',['uint1',['../structuint1.html',1,'']]],
['ulong1',['ulong1',['../structulong1.html',1,'']]],
['ulonglong1',['ulonglong1',['../structulonglong1.html',1,'']]],
['ulonglong3',['ulonglong3',['../structulonglong3.html',1,'']]],
['ulonglong4',['ulonglong4',['../structulonglong4.html',1,'']]],
['ushort1',['ushort1',['../structushort1.html',1,'']]]
];
@@ -36,6 +36,8 @@ var searchData=
['hiperrornodevice',['hipErrorNoDevice',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594ad4406972c318df36d231310a15131c24',1,'hip_runtime_api.h']]],
['hiperrornotready',['hipErrorNotReady',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594aa9638063c8746a9d1fda2b2069a0a9f1',1,'hip_runtime_api.h']]],
['hiperroroutofresources',['hipErrorOutOfResources',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a60c1c080b79bdde9ef5e808f974ac9ed',1,'hip_runtime_api.h']]],
['hiperrorpeeraccessalreadyenabled',['hipErrorPeerAccessAlreadyEnabled',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a5399c146f91246f8b77abcd4ea30e7ac',1,'hip_runtime_api.h']]],
['hiperrorpeeraccessnotenabled',['hipErrorPeerAccessNotEnabled',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a2ee0bf2e64840f253e4a1b12bbaf2d09',1,'hip_runtime_api.h']]],
['hiperrorruntimememory',['hipErrorRuntimeMemory',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a1159eb9a6be66bea740a8bfb61378723',1,'hip_runtime_api.h']]],
['hiperrorruntimeother',['hipErrorRuntimeOther',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594a44f847c5914be2177feac107dcb096d1',1,'hip_runtime_api.h']]],
['hiperrortbd',['hipErrorTbd',['../group__GlobalDefs.html#ggadf5010f6e140a53ecbdf949e73e87594ab556409e11ddb0c4cf77a2f4fc91ea9e',1,'hip_runtime_api.h']]],
+55 -1
View File
@@ -1,4 +1,58 @@
var searchData=
[
['getproperties',['getProperties',['../structihipDevice__t.html#a0abb382f1bcdda80028f9a8307e50561',1,'ihipDevice_t']]]
['hipdevicecanaccesspeer',['hipDeviceCanAccessPeer',['../group__PeerToPeer.html#ga0a1c9ccd775758d9d7d5b5a1f525b719',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int deviceId, int peerDeviceId):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga0a1c9ccd775758d9d7d5b5a1f525b719',1,'hipDeviceCanAccessPeer(int *canAccessPeer, int deviceId, int peerDeviceId):&#160;hip_peer.cpp']]],
['hipdevicedisablepeeraccess',['hipDeviceDisablePeerAccess',['../group__PeerToPeer.html#ga85030c72824fb60aaddc7374ab60481b',1,'hipDeviceDisablePeerAccess(int peerDeviceId):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga85030c72824fb60aaddc7374ab60481b',1,'hipDeviceDisablePeerAccess(int peerDeviceId):&#160;hip_peer.cpp']]],
['hipdeviceenablepeeraccess',['hipDeviceEnablePeerAccess',['../group__PeerToPeer.html#ga0caca59034134d7a7bb893cc1caa653e',1,'hipDeviceEnablePeerAccess(int peerDeviceId, unsigned int flags):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga0caca59034134d7a7bb893cc1caa653e',1,'hipDeviceEnablePeerAccess(int peerDeviceId, unsigned int flags):&#160;hip_peer.cpp']]],
['hipdevicegetattribute',['hipDeviceGetAttribute',['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device):&#160;hip_device.cpp'],['../group__Device.html#gac49518ff2b26b98ea2ec9e9268761a24',1,'hipDeviceGetAttribute(int *pi, hipDeviceAttribute_t attr, int device):&#160;hip_device.cpp']]],
['hipdevicegetcacheconfig',['hipDeviceGetCacheConfig',['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig):&#160;hip_device.cpp'],['../group__Device.html#gaeeffa2456c5430400bea75ecd6ad1e68',1,'hipDeviceGetCacheConfig(hipFuncCache *cacheConfig):&#160;hip_device.cpp']]],
['hipdevicegetsharedmemconfig',['hipDeviceGetSharedMemConfig',['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig):&#160;hip_device.cpp'],['../group__Device.html#ga1bb08f774a34a468d969a8a04791c9bb',1,'hipDeviceGetSharedMemConfig(hipSharedMemConfig *pConfig):&#160;hip_device.cpp']]],
['hipdevicereset',['hipDeviceReset',['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void):&#160;hip_device.cpp'],['../group__Device.html#ga8d57161ae56a8edc46eeda447417bf6c',1,'hipDeviceReset(void):&#160;hip_device.cpp']]],
['hipdevicesetcacheconfig',['hipDeviceSetCacheConfig',['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_device.cpp'],['../group__Device.html#gac2b282179f29c4c0ca7b5391242c6a4c',1,'hipDeviceSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_device.cpp']]],
['hipdevicesetsharedmemconfig',['hipDeviceSetSharedMemConfig',['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config):&#160;hip_device.cpp'],['../group__Device.html#ga9b1f279084e76691cedfbfadf9c717ee',1,'hipDeviceSetSharedMemConfig(hipSharedMemConfig config):&#160;hip_device.cpp']]],
['hipdevicesynchronize',['hipDeviceSynchronize',['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void):&#160;hip_device.cpp'],['../group__Device.html#gaefdc2847fb1d6c3fb1354e827a191ebd',1,'hipDeviceSynchronize(void):&#160;hip_device.cpp']]],
['hipdrivergetversion',['hipDriverGetVersion',['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion):&#160;hip_peer.cpp'],['../group__Version.html#gaf6c342f52d2a29a0aca5cdd89b4dd47c',1,'hipDriverGetVersion(int *driverVersion):&#160;hip_peer.cpp']]],
['hipeventcreate',['hipEventCreate',['../group__Event.html#ga5df2309c9f29ca4c8e669db658d411b4',1,'hipEventCreate(hipEvent_t *event):&#160;hip_event.cpp'],['../group__Event.html#ga5df2309c9f29ca4c8e669db658d411b4',1,'hipEventCreate(hipEvent_t *event):&#160;hip_event.cpp']]],
['hipeventcreatewithflags',['hipEventCreateWithFlags',['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags):&#160;hip_event.cpp'],['../group__Event.html#gae86a5acb1b22b61bc9ecb9c28fc71b75',1,'hipEventCreateWithFlags(hipEvent_t *event, unsigned flags):&#160;hip_event.cpp']]],
['hipeventdestroy',['hipEventDestroy',['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event):&#160;hip_event.cpp'],['../group__Event.html#ga83260357dce0c39e8c6a3c74ec97484c',1,'hipEventDestroy(hipEvent_t event):&#160;hip_event.cpp']]],
['hipeventelapsedtime',['hipEventElapsedTime',['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop):&#160;hip_event.cpp'],['../group__Event.html#gad4128b815cb475c8e13c7e66ff6250b7',1,'hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop):&#160;hip_event.cpp']]],
['hipeventquery',['hipEventQuery',['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event):&#160;hip_event.cpp'],['../group__Event.html#ga5d12d7b798b5ceb5932d1ac21f5ac776',1,'hipEventQuery(hipEvent_t event):&#160;hip_event.cpp']]],
['hipeventrecord',['hipEventRecord',['../group__Event.html#ga553b6f7a8e7b7dd9536d8a64c24d7e29',1,'hipEventRecord(hipEvent_t event, hipStream_t stream):&#160;hip_event.cpp'],['../group__Event.html#ga553b6f7a8e7b7dd9536d8a64c24d7e29',1,'hipEventRecord(hipEvent_t event, hipStream_t stream):&#160;hip_event.cpp']]],
['hipeventsynchronize',['hipEventSynchronize',['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event):&#160;hip_event.cpp'],['../group__Event.html#ga1f72d98ba5d6f7dc3da54e0c41fe38b1',1,'hipEventSynchronize(hipEvent_t event):&#160;hip_event.cpp']]],
['hipfree',['hipFree',['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr):&#160;hip_memory.cpp'],['../group__Memory.html#ga740d08da65cae1441ba32f8fedb863d1',1,'hipFree(void *ptr):&#160;hip_memory.cpp']]],
['hipfreehost',['hipFreeHost',['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr) __attribute__((deprecated(&quot;use hipHostFree instead&quot;))):&#160;hip_memory.cpp'],['../group__Memory.html#gad2164cc3d49da53052f4b83b789e90c9',1,'hipFreeHost(void *ptr):&#160;hip_memory.cpp']]],
['hipfuncsetcacheconfig',['hipFuncSetCacheConfig',['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache config):&#160;hip_device.cpp'],['../group__Device.html#gadd94a910c2b840833cc325b1e5425702',1,'hipFuncSetCacheConfig(hipFuncCache cacheConfig):&#160;hip_device.cpp']]],
['hipgetdevice',['hipGetDevice',['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device):&#160;hip_device.cpp'],['../group__Device.html#gaffc83567f2df3bbe2d37a19872d60f24',1,'hipGetDevice(int *device):&#160;hip_device.cpp']]],
['hipgetdevicecount',['hipGetDeviceCount',['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count):&#160;hip_device.cpp'],['../group__Device.html#ga8555d5c76d88c50ddbf54ae70b568394',1,'hipGetDeviceCount(int *count):&#160;hip_device.cpp']]],
['hipgetdeviceproperties',['hipGetDeviceProperties',['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *prop, int device):&#160;hip_device.cpp'],['../group__Device.html#ga77c20744e2a88c31440992d6c7754b5f',1,'hipGetDeviceProperties(hipDeviceProp_t *props, int device):&#160;hip_device.cpp']]],
['hipgeterrorname',['hipGetErrorName',['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error):&#160;hip_error.cpp'],['../group__Error.html#ga88c474d77635523dbf6ca67be7b56999',1,'hipGetErrorName(hipError_t hip_error):&#160;hip_error.cpp']]],
['hipgeterrorstring',['hipGetErrorString',['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error):&#160;hip_error.cpp'],['../group__Error.html#ga5959779a654bbc98ffe6d36ab536740a',1,'hipGetErrorString(hipError_t hip_error):&#160;hip_error.cpp']]],
['hipgetlasterror',['hipGetLastError',['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError(void):&#160;hip_error.cpp'],['../group__Error.html#ga533daeb9114d7fc2db8d867adf9e419b',1,'hipGetLastError():&#160;hip_error.cpp']]],
['hiphccgetaccelerator',['hipHccGetAccelerator',['../hip__hcc_8cpp.html#a0d24b3157fd1b16d38672bb157ec4cd4',1,'hip_hcc.cpp']]],
['hiphccgetacceleratorview',['hipHccGetAcceleratorView',['../hip__hcc_8cpp.html#a1a7087ea9c3c3323270d7cce73650b44',1,'hip_hcc.cpp']]],
['hiphostfree',['hipHostFree',['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr):&#160;hip_memory.cpp'],['../group__Memory.html#ga2e543f58ee4544e317cd695d6d82e0a3',1,'hipHostFree(void *ptr):&#160;hip_memory.cpp']]],
['hiphostgetdevicepointer',['hipHostGetDevicePointer',['../group__Memory.html#ga8fa7a0478020b835a24785cd6bb89725',1,'hip_runtime_api.h']]],
['hiphostgetflags',['hipHostGetFlags',['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr):&#160;hip_memory.cpp'],['../group__Memory.html#ga4d26915873b3e3534ceb4dc310f8709a',1,'hipHostGetFlags(unsigned int *flagsPtr, void *hostPtr):&#160;hip_memory.cpp']]],
['hiphostmalloc',['hipHostMalloc',['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t size, unsigned int flags):&#160;hip_memory.cpp'],['../group__Memory.html#gaad40bc7d97ccc799403ef5a9a8c246e1',1,'hipHostMalloc(void **ptr, size_t sizeBytes, unsigned int flags):&#160;hip_memory.cpp']]],
['hiphostregister',['hipHostRegister',['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags):&#160;hip_memory.cpp'],['../group__Memory.html#gab8258f051e1a1f7385f794a15300e674',1,'hipHostRegister(void *hostPtr, size_t sizeBytes, unsigned int flags):&#160;hip_memory.cpp']]],
['hiphostunregister',['hipHostUnregister',['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr):&#160;hip_memory.cpp'],['../group__Memory.html#ga4c9e1810b9f5858d36c4d28c91c86924',1,'hipHostUnregister(void *hostPtr):&#160;hip_memory.cpp']]],
['hipmalloc',['hipMalloc',['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t size):&#160;hip_memory.cpp'],['../group__Memory.html#ga4c6fcfe80010069d2792780d00dcead2',1,'hipMalloc(void **ptr, size_t sizeBytes):&#160;hip_memory.cpp']]],
['hipmallochost',['hipMallocHost',['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t size) __attribute__((deprecated(&quot;use hipHostMalloc instead&quot;))):&#160;hip_memory.cpp'],['../group__Memory.html#gad3d3cdf82eb0058fc9eac1f939cd9d30',1,'hipMallocHost(void **ptr, size_t sizeBytes):&#160;hip_memory.cpp']]],
['hipmemcpy',['hipMemcpy',['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind):&#160;hip_memory.cpp'],['../group__Memory.html#gac1a055d288302edd641c6d7416858e1e',1,'hipMemcpy(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind):&#160;hip_memory.cpp']]],
['hipmemcpyasync',['hipMemcpyAsync',['../group__Memory.html#gad55fa9f5980b711bc93c52820149ba18',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream):&#160;hip_memory.cpp'],['../group__Memory.html#gad55fa9f5980b711bc93c52820149ba18',1,'hipMemcpyAsync(void *dst, const void *src, size_t sizeBytes, hipMemcpyKind kind, hipStream_t stream):&#160;hip_memory.cpp']]],
['hipmemcpypeer',['hipMemcpyPeer',['../group__PeerToPeer.html#ga5512f45e25c08052667c8ffe7162333b',1,'hipMemcpyPeer(void *dst, int dstDeviceId, const void *src, int srcDeviceId, size_t sizeBytes):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga5512f45e25c08052667c8ffe7162333b',1,'hipMemcpyPeer(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes):&#160;hip_peer.cpp']]],
['hipmemcpypeerasync',['hipMemcpyPeerAsync',['../group__PeerToPeer.html#ga216f951370c931d22e80c089ab724ed9',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream):&#160;hip_peer.cpp'],['../group__PeerToPeer.html#ga216f951370c931d22e80c089ab724ed9',1,'hipMemcpyPeerAsync(void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream):&#160;hip_peer.cpp']]],
['hipmemcpytosymbol',['hipMemcpyToSymbol',['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t sizeBytes, size_t offset, hipMemcpyKind kind):&#160;hip_memory.cpp'],['../group__Memory.html#ga131ac5c1ba04e186112491cb9bf964bc',1,'hipMemcpyToSymbol(const char *symbolName, const void *src, size_t count, size_t offset, hipMemcpyKind kind):&#160;hip_memory.cpp']]],
['hipmemgetinfo',['hipMemGetInfo',['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total):&#160;hip_memory.cpp'],['../group__Memory.html#ga311c3e246a21590de14478b8bd063be2',1,'hipMemGetInfo(size_t *free, size_t *total):&#160;hip_memory.cpp']]],
['hipmemset',['hipMemset',['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes):&#160;hip_memory.cpp'],['../group__Memory.html#gac7441e74affcce4b8b69dba996c5ebc4',1,'hipMemset(void *dst, int value, size_t sizeBytes):&#160;hip_memory.cpp']]],
['hipmemsetasync',['hipMemsetAsync',['../group__Memory.html#gae7d90e14c387e49f10db597f12915c54',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream):&#160;hip_memory.cpp'],['../group__Memory.html#gae7d90e14c387e49f10db597f12915c54',1,'hipMemsetAsync(void *dst, int value, size_t sizeBytes, hipStream_t stream):&#160;hip_memory.cpp']]],
['hippeekatlasterror',['hipPeekAtLastError',['../group__Error.html#ga1dd660bc739f7e13edd34615660f0148',1,'hip_runtime_api.h']]],
['hippointergetattributes',['hipPointerGetAttributes',['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr):&#160;hip_memory.cpp'],['../group__Memory.html#ga3d68ba64959615d4ab84f10caa12433b',1,'hipPointerGetAttributes(hipPointerAttribute_t *attributes, void *ptr):&#160;hip_memory.cpp']]],
['hipsetdevice',['hipSetDevice',['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device):&#160;hip_device.cpp'],['../group__Device.html#ga8ec0b093af0adadc7fe98bf33fa21620',1,'hipSetDevice(int device):&#160;hip_device.cpp']]],
['hipsetdeviceflags',['hipSetDeviceFlags',['../group__Device.html#ga6e54db382768827e84725632018307aa',1,'hip_runtime_api.h']]],
['hipstreamcreate',['hipStreamCreate',['../group__Stream.html#gaff5b62d6e9502d80879f7176f4d03102',1,'hipStreamCreate(hipStream_t *stream):&#160;hip_stream.cpp'],['../group__Stream.html#gaff5b62d6e9502d80879f7176f4d03102',1,'hipStreamCreate(hipStream_t *stream):&#160;hip_stream.cpp']]],
['hipstreamcreatewithflags',['hipStreamCreateWithFlags',['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags):&#160;hip_stream.cpp'],['../group__Stream.html#gaf2382e3cc6632332a8983a0f58e43494',1,'hipStreamCreateWithFlags(hipStream_t *stream, unsigned int flags):&#160;hip_stream.cpp']]],
['hipstreamdestroy',['hipStreamDestroy',['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream):&#160;hip_stream.cpp'],['../group__Stream.html#ga3076a3499ed2c7821311006100bb95ec',1,'hipStreamDestroy(hipStream_t stream):&#160;hip_stream.cpp']]],
['hipstreamgetflags',['hipStreamGetFlags',['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags):&#160;hip_stream.cpp'],['../group__Stream.html#ga3249555a26439591b8873f70b39bb116',1,'hipStreamGetFlags(hipStream_t stream, unsigned int *flags):&#160;hip_stream.cpp']]],
['hipstreamsynchronize',['hipStreamSynchronize',['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream):&#160;hip_stream.cpp'],['../group__Stream.html#gabbfb9f573a6ebe8c478605ecb5504a74',1,'hipStreamSynchronize(hipStream_t stream):&#160;hip_stream.cpp']]],
['hipstreamwaitevent',['hipStreamWaitEvent',['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags):&#160;hip_stream.cpp'],['../group__Stream.html#gacdd84c8f8ef1539c96c57c1d5bcae633',1,'hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int flags):&#160;hip_stream.cpp']]]
];
-4
View File
@@ -1,4 +0,0 @@
var searchData=
[
['texture_20reference_20management',['Texture Reference Management',['../group__Texture.html',1,'']]]
];
+2 -2
View File
@@ -8,9 +8,9 @@
var indexSectionsWithContent =
{
0: "_abcdefghilmnoprstwxyz",
1: "dfhist",
1: "dfhilst",
2: "h",
3: "gh",
3: "h",
4: "achilmnprstwxyz",
5: "dh",
6: "h",
@@ -1,5 +1,6 @@
var searchData=
[
['hipfunccache',['hipFuncCache',['../group__GlobalDefs.html#gaad15dc7939a0a25b16e4aa161fb41eee',1,'hip_runtime_api.h']]],
['hipmemcpykind',['hipMemcpyKind',['../group__GlobalDefs.html#ga0c04e67413ce030817361f02673e5c85',1,'hip_runtime_api.h']]],
['hipsharedmemconfig',['hipSharedMemConfig',['../group__GlobalDefs.html#ga6b1ca424fa26a5fb718937d662eaee7f',1,'hip_runtime_api.h']]]
];
+1 -4
View File
@@ -16,8 +16,5 @@ var searchData=
['hasthreadfencesystem',['hasThreadFenceSystem',['../structhipDeviceArch__t.html#ac2818e3b91cba8beb36741e9867bb887',1,'hipDeviceArch_t']]],
['haswarpballot',['hasWarpBallot',['../structhipDeviceArch__t.html#af1e934a8a5106995bcc256287585564c',1,'hipDeviceArch_t']]],
['haswarpshuffle',['hasWarpShuffle',['../structhipDeviceArch__t.html#a3d922e8fc97ca1e8ecc39600b138fa2d',1,'hipDeviceArch_t']]],
['haswarpvote',['hasWarpVote',['../structhipDeviceArch__t.html#a35bde017352eca1d4e0eceb3bf79f274',1,'hipDeviceArch_t']]],
['hip_5flaunch_5fblocking',['HIP_LAUNCH_BLOCKING',['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#ga8049b329f2663b4572d81e7a9aa8a155',1,'HIP_LAUNCH_BLOCKING():&#160;hip_hcc2.cpp']]],
['hip_5fprint_5fenv',['HIP_PRINT_ENV',['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#ga1e1c85dbb250f1acfb484c1be1f3b28a',1,'HIP_PRINT_ENV():&#160;hip_hcc2.cpp']]],
['hip_5ftrace_5fapi',['HIP_TRACE_API',['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API():&#160;hip_hcc.cpp'],['../group__HIP-ENV.html#gaae9c541f3e25b8f002762337a03fec28',1,'HIP_TRACE_API():&#160;hip_hcc2.cpp']]]
['haswarpvote',['hasWarpVote',['../structhipDeviceArch__t.html#a35bde017352eca1d4e0eceb3bf79f274',1,'hipDeviceArch_t']]]
];
@@ -3,7 +3,7 @@
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta name="generator" content="Doxygen 1.8.6">
<link rel="stylesheet" type="text/css" href="search.css"/>
<script type="text/javascript" src="classes_7.js"></script>
<script type="text/javascript" src="variables_e.js"></script>
<script type="text/javascript" src="search.js"></script>
</head>
<body class="SRPage">
@@ -0,0 +1,4 @@
var searchData=
[
['z',['z',['../structdim3.html#a866e38993ecc4e76fd47311236c16b04',1,'dim3']]]
];